#!/bin/bash

# This helper script will handle deploying aurora cluster and creating an external service
#
# /scripts/deploy-aurora.sh
#

set -e

source /scripts/utils.sh
source /scripts/terraform.sh

check_access ${appsNamespace} services
check_access ${appsNamespace} configmaps

tfAdditionalVarsFile=${tfRoot}/additional_settings.auto.tfvars

echo "password = \"${primaryPassword}\"" > ${tfAdditionalVarsFile}

terraform_init
export TF_X_CONCISE_DIFF=0
terraform_plan
unset TF_X_CONCISE_DIFF
terraform_apply
terraform_output

if [ ${awsDeployment} == "true" ]; then
  print_header "Checking for the aurora endpoint"

  terraform_get aurora_postgres_cluster_endpoint auroraPostgresClusterEndpoint

  create_external_service ${dbServiceClusterEndpointShortName} ${appsNamespace} ${auroraPostgresClusterEndpoint}

  terraform_get aurora_postgres_cluster_reader_endpoint auroraPostgresClusterReaderEndpoint

  create_hostname_configmap ${namingPrefix}-endpoint ${appsNamespace} "--from-literal=endpoint=${auroraPostgresClusterEndpoint}" "--from-literal=readerEndpoint=${auroraPostgresClusterReaderEndpoint}"
  create_hostname_configmap ${namingPrefix}-endpoint ${infraNamespace} "--from-literal=endpoint=${auroraPostgresClusterEndpoint}" "--from-literal=readerEndpoint=${auroraPostgresClusterReaderEndpoint}"

  # Deprecated - will be removed in 1.0 release
  create_external_service ${dbServiceClusterReaderEndpointShortName} ${appsNamespace} ${auroraPostgresClusterReaderEndpoint}
fi

cprint "$0 done"
